Module: Punctuated
- Defined in:
- lib/punctuated.rb,
lib/punctuated/parsed.rb,
lib/punctuated/options.rb,
lib/punctuated/version.rb,
lib/punctuated/component.rb,
lib/punctuated/constants.rb,
lib/punctuated/parsed/parsing.rb,
lib/punctuated/parsed/operations.rb,
lib/punctuated/parsed/composition.rb
Defined Under Namespace
Modules: Options Classes: Component, Parsed, Terminal, Wrapper
Constant Summary collapse
- VERSION =
"0.9.0"- TERMINAL =
Sentence-terminal characters recognised by Unicode, plus inverted sentence terminals omitted from STerm.
/[\p{STerm}¡¿⸘]/u- WRAPPER =
Opening, closing and quotation characters that may surround a sentence terminal.
/(?:[\p{Ps}\p{Pe}\p{Pi}\p{Pf}]|\p{Quotation_Mark})/u- WHITESPACE =
Whitespace deliberately uses Ruby's normal \s semantics, as required by the public contract.
/\s/u
Class Method Summary collapse
-
.new(string, options = nil, **keywords) ⇒ Object
(also: parse)
Parse is an alias of new so either entry point produces the same mutable representation.
Class Method Details
.new(string, options = nil, **keywords) ⇒ Object Also known as: parse
Parse is an alias of new so either entry point produces the same mutable representation.
10 11 12 |
# File 'lib/punctuated.rb', line 10 def new(string, = nil, **keywords) Parsed.new(string, , **keywords) end |